
/*
 * servotest.c:
 *	Simple test program to test the wiringPi functions
 * compile with gcc R3.c -I/usr/local/include -L/usr/local/lib -lwiringPi -lm -o R3C1
 */

#include <wiringPi.h>

#include <stdio.h>
#include <stdlib.h>
#include <stdint.h>
#include <math.h>
#include <termios.h>
#include <string.h>
#include <time.h>

static void usage(){
  printf("usage:\n");
  printf("R3C1 [actuator] [value]\n");
  printf("v - Servo vertical camera angle (900 - 1700)\n");
  printf("s - Servo steering angle (400 - 1700)\n");
  printf("f - Drive forward (0 - 50)\n");
  printf("b - Drive backward (0 - 50)\n");
  printf("l - Light intensity (0 - 4)\n");
}


int main (int argc, char **argv){
  int i, i2, pulse;
  int key=0;
  int GPIO[17];
  int GPIOvalue[17];
  int x=0, frequency=100, currentValue;
  int GPIOstate[17];
  int pulseCount = 0;
  int oldState=0;
  long pulseDiff=0;
  struct timeval lastPulse, currentPulse; 
  int oldIrId = 0;
  FILE *IRID;
  char IrFileName[]="IrModuleInRange.txt";
  char charTemp[1000]="";
  int MaximumStateCount = 140;
  int CurrentStateCount = 0;
  int CameraAngle = -1;
  int DriveDistance = -1;
  int DriveDirection = 0;
  int SteeringAngle = -1;
  int argEnd = 2;
  int durationEnd = 50;

  //Mapping between winringPi and pin connector Raspberry Pi
  GPIO[0]=8;
  GPIO[1]=9;
  GPIO[2]=7;
  GPIO[3]=10;
  GPIO[4]=11;
  GPIO[5]=12;
  GPIO[6]=13;
  GPIO[7]=14;
  GPIO[8]=15;
  GPIO[9]=16;
  GPIO[10]=0;
  GPIO[11]=1;
  GPIO[12]=2;
  GPIO[13]=3;
  GPIO[14]=4;
  GPIO[15]=5;
  GPIO[16]=6;


  if (wiringPiSetup () == -1)
    exit (1) ;

  for(i=0; i<17; i++){
    pinMode (GPIO[i], OUTPUT);
  }


  if(argc < 2){
    usage();
    return(0);
  }
  
  if(strcmp(argv[1], "o") == 0){
    digitalWrite(GPIO[3], 0);
    digitalWrite(GPIO[5], 0);
    digitalWrite(GPIO[6], 0);
    digitalWrite(GPIO[7], 0); 
    for(i=0;i<50;i++){
      digitalWrite(GPIO[12], 0);
      usleep(1000);
      digitalWrite(GPIO[12], 1);
      usleep(20000 - 1000);
    }
    for(i=0;i<50;i++){
      digitalWrite(GPIO[13], 0);
      usleep(1000);
      digitalWrite(GPIO[13], 1);
      usleep(20000 - 1000);
    }
  }

  if(strcmp(argv[1], "O") == 0){
    digitalWrite(GPIO[3], 0);
    digitalWrite(GPIO[5], 0);
    digitalWrite(GPIO[6], 0);
    digitalWrite(GPIO[7], 0); 
  }

  if(strcmp(argv[1], "v") == 0){
    if(atoi(argv[2]) < 900 || atoi(argv[2]) > 1700){
      usage();
      return(0);
    }
    printf("Adjusting camera angle to %s\n", argv[2]);
    for(i=0;i<50;i++){
      digitalWrite(GPIO[12], 0);
      usleep(atoi(argv[2]));
      digitalWrite(GPIO[12], 1);
      usleep(20000 - atoi(argv[2]));
    }
  }

  if(strcmp(argv[1], "s") == 0){
    if(atoi(argv[2]) < 400 || atoi(argv[2]) > 1700){
      usage();
      return(0);
    }
    printf("Adjusting steering to %s\n", argv[2]);
    for(i = 0; i < 50; i++){
      digitalWrite(GPIO[13], 0);
      usleep(atoi(argv[2]));
      digitalWrite(GPIO[13], 1);
      usleep(20000 - atoi(argv[2]));
    }
  }

  if(strcmp(argv[1], "b") == 0){
    if(atoi(argv[2]) < 0 || atoi(argv[2]) > 2000){
      usage();
      return(0);
    }
    printf("Driving backward %s\n", argv[2]);
    for(i=0;i<atoi(argv[2]);i++){
      digitalWrite(GPIO[10], 0);
      usleep(1000);
      digitalWrite(GPIO[10], 1);
      usleep(20000 - 1000);
    }
  }

  if(strcmp(argv[1], "f") == 0){
    if(atoi(argv[2]) < 0 || atoi(argv[2]) > 2000){
      usage();
      return(0);
    }
    printf("Driving forward %s\n", argv[2]);
    for(i=0;i<atoi(argv[2]);i++){
      digitalWrite(GPIO[10], 0);
      usleep(1300);
      digitalWrite(GPIO[10], 1);
      usleep(20000 - 1300);
    }
  }

  if(strcmp(argv[1], "l") == 0){
    if(atoi(argv[2]) < 0 || atoi(argv[2]) > 4){
      usage();
      return(0);
    }
    printf("Switching light intensity to %s\n", argv[2]);
    if(strcmp(argv[2], "0") == 0){
      digitalWrite(GPIO[3], 0);
      digitalWrite(GPIO[5], 0);
      digitalWrite(GPIO[6], 0);
      digitalWrite(GPIO[7], 0);
    }
    if(strcmp(argv[2], "1") == 0){
      digitalWrite(GPIO[3], 0);
      digitalWrite(GPIO[5], 1);
      digitalWrite(GPIO[6], 0);
      digitalWrite(GPIO[7], 0);
    }
    if(strcmp(argv[2], "2") == 0){
      digitalWrite(GPIO[3], 1);
      digitalWrite(GPIO[5], 1);
      digitalWrite(GPIO[6], 0);
      digitalWrite(GPIO[7], 0);
    }
    if(strcmp(argv[2], "3") == 0){
      digitalWrite(GPIO[3], 1);
      digitalWrite(GPIO[5], 1);
      digitalWrite(GPIO[6], 1);
      digitalWrite(GPIO[7], 0);
    }
    if(strcmp(argv[2], "4") == 0){
      digitalWrite(GPIO[3], 1);
      digitalWrite(GPIO[5], 1);
      digitalWrite(GPIO[6], 1);
      digitalWrite(GPIO[7], 1);
    }
  }


  return 0 ;
}
